/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Conrad Carlen <ccarlen@netscape.com>
 *   Don Cone <dcone@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

%{ C++
#include <PMApplication.h>
%}

/**
 * Native types
 */
native nsPMPageFormat(PMPageFormat);
native nsPMPrintSettings(PMPrintSettings);
native nsPMPrintSession(PMPrintSession);

/**
 * Simplified PrintSettings for OSX interface 
 *
 * @status UNDER_REVIEW
 */
[scriptable, uuid(CD2A0A4F-0DE9-4c51-9232-42668F559F94)]

interface nsIPrintSettingsX : nsISupports
{
  /**
   * nativePrintSession attribute
   *
   * Convenience method which gets the nsIPrintSession
   * and returns its native session object
   *
   * Does NOT do PMRetain() on result.
   */
  [noscript] readonly attribute nsPMPrintSession nativePrintSession;

  /**
   * PMPageFormat and PMPrintSettings attributes
   *
   * Getter does NOT do PMRetain() on result.
   * Setter does PMRetain() on parameter.
   */
  [noscript] attribute nsPMPageFormat pMPageFormat;

  [noscript] attribute nsPMPrintSettings pMPrintSettings;

  /**
   * readPageFormatFromPrefs and writePageFormatToPrefs
   *
   * Read and write a flattened PMPageFormat to/from prefs.
   * This also contains any custom data we appended to the dialog
   */
  [noscript] void readPageFormatFromPrefs();
  [noscript] void writePageFormatToPrefs();
};
